glue-core documentation
========================

Glue is a Python library to explore relationships within and among related datasets.

This is the documentation for the glue-core frontend-independent library for the
glue project, and is primary intended for advanced users and developers. For the
main documentation about the desktop glue application, see http://docs.glueviz.org.


API
---

.. toctree::
   :maxdepth: 1

   api.rst
